@@ -85,9 +85,11 @@ class SystemEnvironment(object):
     WAIT_ON_ERROR = 'OTOPI_WAIT_ON_ERROR'
     FORCE_FAIL_STAGE = 'OTOPI_FORCE_FAIL_STAGE'
     FORCE_FAIL_PRIORITY = 'OTOPI_FORCE_FAIL_PRIORITY'
+    TEST_COMMAND = 'OTOPI_TEST_COMMAND'
     ALLOW_PRIORITY_OVERRIDE = 'OTOPI_ALLOW_PRIORITY_OVERRIDE'
     ALLOW_LEGACY_BUILDSEQ = 'OTOPI_ALLOW_LEGACY_BUILDSEQ'
     COVERAGE = 'OTOPI_COVERAGE'
+    SYS_PATH = 'PATH'
 
 
 @util.export
